import { Consumer, ConsumerConfig, ConsumerRunConfig, ConsumerSubscribeTopic, Producer, ProducerConfig, ProducerRecord, RecordMetadata } from 'kafkajs';
export declare abstract class EventBus {
    abstract get producer(): Producer;
    abstract get consumer(): Consumer;
    abstract get isProducerReq(): boolean;
    abstract get isConsumerReq(): boolean;
    abstract set clientId(clientId: string);
    abstract set brokers(brokers: string[]);
    abstract set producerConfig(producerConfig: ProducerConfig);
    abstract set consumerConfig(consumerConfig: ConsumerConfig);
    abstract setup(isProducerReq: boolean, isConsumerReq: boolean): void;
    abstract init(): void;
    abstract onConnect(): Promise<void>;
    abstract onProduce(record: ProducerRecord): Promise<RecordMetadata[]>;
    abstract onConsume(topic: ConsumerSubscribeTopic): Promise<void>;
    abstract onListenEvents(config: ConsumerRunConfig): Promise<void>;
}
export declare class KafkaClient extends EventBus {
    private static _instance;
    private _isProducerReq;
    private _isConsumerReq;
    private _clientId;
    private _brokers;
    private _kafka;
    private _producer;
    private _consumer;
    private _producerConfig;
    private _consumerConfig;
    private constructor();
    static getInstance(): KafkaClient;
    get producer(): Producer;
    get consumer(): Consumer;
    get isProducerReq(): boolean;
    get isConsumerReq(): boolean;
    set clientId(clientId: string);
    set brokers(brokers: string[]);
    set producerConfig(producerConfig: ProducerConfig);
    set consumerConfig(consumerConfig: ConsumerConfig);
    private producerInit;
    private consumerInit;
    setup(isProducerReq: boolean, isConsumerReq: boolean): void;
    init(): void;
    onConnect(): Promise<void>;
    onProduce(record: ProducerRecord): Promise<RecordMetadata[]>;
    onConsume(topic: ConsumerSubscribeTopic): Promise<void>;
    onListenEvents(config: ConsumerRunConfig): Promise<void>;
}
