import { Express } from 'express';
import { ConsumerConfig, ProducerConfig } from 'kafkajs';
import { DefaultConfig, LogPath } from '../foundation';
import { CronJob, Routes } from '../interfaces';
declare abstract class BaseLoader {
    abstract set config(config: DefaultConfig);
    abstract set logPath(logPath: LogPath);
    abstract set cronJob(cronJob: CronJob);
    abstract set routes(routes: Routes);
    abstract set app(app: Express);
    abstract set dbConnectionString(dbConnectionString: string);
    abstract set authUrl(authUrl: string);
    abstract set adminName(adminName: string);
    abstract set adminPassword(adminPassword: string);
    abstract set clientId(clientId: string);
    abstract set brokers(brokers: string[]);
    abstract set producerConfig(config: ProducerConfig);
    abstract set consumerConfig(config: ConsumerConfig);
    abstract setup(isProcessRequired: boolean, isNconfRequired: boolean, isWinstonRequired: boolean, isDatabaseRequired: boolean, isCronRequired: boolean, isRoutesRequired: boolean, isStorageRequired: boolean, isKafkaClientRequired: boolean, isSSORequired: boolean): void;
    abstract load(): Promise<boolean>;
}
declare class Loader extends BaseLoader {
    private static _instance;
    private _isProcessRequired;
    private _isNconfRequired;
    private _isWinstonRequired;
    private _isDatabaseRequired;
    private _isCronRequired;
    private _isRoutesRequired;
    private _isStorageRequired;
    private _isKafkaClientRequired;
    private _isSSORequired;
    private _environment;
    private _config;
    private _logPath;
    private _dbConnectionString;
    private _authUrl;
    private _adminName;
    private _adminPassword;
    private _cronJob;
    private _routes;
    private _app;
    private _clientId;
    private _brokers;
    private _producerConfig;
    private _consumerConfig;
    private constructor();
    static getInstance(): Loader;
    set config(config: DefaultConfig);
    set logPath(logPath: LogPath);
    set dbConnectionString(dbConnectionString: string);
    set authUrl(url: string);
    set adminName(name: string);
    set adminPassword(password: string);
    set cronJob(cronJob: CronJob);
    set routes(routes: Routes);
    set app(app: Express);
    set clientId(clientId: string);
    set brokers(brokers: string[]);
    set producerConfig(config: ProducerConfig);
    set consumerConfig(config: ConsumerConfig);
    setup(isProcessRequired: boolean, isNconfRequired: boolean, isWinstonRequired: boolean, isDatabaseRequired: boolean, isCronRequired: boolean, isRoutesRequired: boolean, isStorageRequired: boolean, isKafkaClientRequired: boolean, isSSORequired: boolean): void;
    load(): Promise<boolean>;
}
export { Loader, BaseLoader };
